@@ -40,9 +40,13 @@ class ArdourDialog : public Gtk::Dialog
 	ArdourDialog (Gtk::Window& parent, std::string title, bool modal = false, bool use_separator = false);
 	~ArdourDialog();
 
+	static int close_all_current_dialogs (int response);
+
+	bool on_key_press_event (GdkEventKey *);
 	bool on_enter_notify_event (GdkEventCrossing*);
 	bool on_leave_notify_event (GdkEventCrossing*);
 	void on_unmap ();
+	void on_show ();
 
 	ARDOUR::Session *session;
 
@@ -53,6 +57,11 @@ class ArdourDialog : public Gtk::Dialog
 	virtual void session_gone () {
 		set_session (0);
 	}
+
+	static void close_all_dialogs () { CloseAllDialogs(); }
+
+  private:
+	static sigc::signal<void> CloseAllDialogs;
 };
 
 #endif // __ardour_dialog_h__
