@@ -73,6 +73,9 @@ class AudioStreamView : public StreamView
 
 	void foreach_crossfadeview (void (CrossfadeView::*pmf)(void));
 
+	void show_all_fades ();
+	void hide_all_fades ();
+
 	void show_all_xfades ();
 	void hide_all_xfades ();
 	void hide_xfades_involving (AudioRegionView&);
@@ -83,7 +86,7 @@ class AudioStreamView : public StreamView
 	void rec_peak_range_ready (nframes_t start, nframes_t cnt, boost::weak_ptr<ARDOUR::Source> src); 
 	void update_rec_regions ();
 	
-	void add_region_view_internal (boost::shared_ptr<ARDOUR::Region>, bool wait_for_waves);
+	void add_region_view_internal (boost::shared_ptr<ARDOUR::Region>, bool wait_for_waves, bool recording = false);
 	void remove_region_view (boost::weak_ptr<ARDOUR::Region> );
 	void remove_audio_region_view (boost::shared_ptr<ARDOUR::AudioRegion> );
 
@@ -109,6 +112,8 @@ class AudioStreamView : public StreamView
 	nframes_t             last_rec_peak_frame;
 	map<boost::shared_ptr<ARDOUR::Source>, bool> rec_peak_ready_map;
 
+	bool outline_region;
+
 	Editing::WaveformShape     _waveform_shape;
 	Editing::WaveformScale     _waveform_scale;
 };
