@@ -83,6 +83,7 @@ EngineControl::EngineControl ()
 	strings.push_back (_("48000Hz"));
 	strings.push_back (_("88200Hz"));
 	strings.push_back (_("96000Hz"));
+	strings.push_back (_("176400Hz"));
 	strings.push_back (_("192000Hz"));
 	set_popdown_strings (sample_rate_combo, strings);
 	sample_rate_combo.set_active_text ("48000Hz");
@@ -437,17 +438,9 @@ EngineControl::build_command_line (vector<string>& cmd)
 		cmd.push_back ("netjack");
 	} else if (driver == X_("FFADO")) {
 		using_ffado = true;
-
-		/* do this until FFADO becomes the standard */
-
-		char* hack = getenv ("ARDOUR_FIREWIRE_DRIVER_NAME");
-
-		if (hack) {
-			cmd.push_back (hack);
-		} else {
-			cmd.push_back ("freebob");
-		}
-
+                cmd.push_back ("ffado");
+	} else if (driver == X_("Freebob")) {
+                cmd.push_back ("freebob");
 	} else if ( driver == X_("Dummy")) {
 		using_dummy = true;
 		cmd.push_back ("dummy");
@@ -675,7 +668,7 @@ EngineControl::enumerate_coreaudio_devices ()
 	// (code snippet gently "borrowed" from St?hane Letz jackdmp;)
 	OSStatus err;
 	Boolean isWritable;
-	size_t outSize = sizeof(isWritable);
+	UInt32 outSize = sizeof(isWritable);
 
 	backend_devs.clear ();
 
@@ -691,8 +684,8 @@ EngineControl::enumerate_coreaudio_devices ()
 		if (err == noErr) {
 			// Look for the CoreAudio device name...
 			char coreDeviceName[256];
-			size_t nameSize;
-
+			UInt32 nameSize;
+			
 			for (int i = 0; i < numCoreDevices; i++) {
 
 				nameSize = sizeof (coreDeviceName);
@@ -905,7 +898,14 @@ EngineControl::driver_changed ()
 uint32_t
 EngineControl::get_rate ()
 {
-	return atoi (sample_rate_combo.get_active_text ());
+	double r = atof (sample_rate_combo.get_active_text ());
+	/* the string may have been translated with an abbreviation for
+	 * thousands, so use a crude heuristic to fix this.
+	 */
+	if (r < 1000.0) {
+		r *= 1000.0;
+	}
+	return lrint (r);
 }
 
 void
