@@ -44,6 +44,7 @@ using namespace ArdourCanvas;
 const TimeAxisViewItem::Visibility TapeAudioRegionView::default_tape_visibility
 	= TimeAxisViewItem::Visibility (
 		TimeAxisViewItem::ShowNameHighlight |
+		TimeAxisViewItem::ShowNameText |
 		TimeAxisViewItem::ShowFrame |
 		TimeAxisViewItem::HideFrameRight |
 		TimeAxisViewItem::FullWidthNameHighlight);
@@ -53,7 +54,7 @@ TapeAudioRegionView::TapeAudioRegionView (ArdourCanvas::Group *parent, RouteTime
 					  double spu, 
 					  Gdk::Color& basic_color)
 
-	: AudioRegionView (parent, tv, r, spu, basic_color, 
+	: AudioRegionView (parent, tv, r, spu, basic_color, false,
 			   TimeAxisViewItem::Visibility ((r->position() != 0) ? default_tape_visibility : 
 							 TimeAxisViewItem::Visibility (default_tape_visibility|TimeAxisViewItem::HideFrameLeft)))
 {
@@ -62,7 +63,11 @@ TapeAudioRegionView::TapeAudioRegionView (ArdourCanvas::Group *parent, RouteTime
 void
 TapeAudioRegionView::init (Gdk::Color& basic_color, bool wfw)
 {
-	AudioRegionView::init(basic_color, wfw);
+	/* never wait for data: always just create the waves, connect once and then
+	   we'll update whenever we need to.
+	*/
+
+	AudioRegionView::init(basic_color, false);
 
 	/* every time the wave data changes and peaks are ready, redraw */
 	
