@@ -83,6 +83,7 @@ class AutomationList : public PBD::StatefulDestructible
 
 	void freeze();
 	void thaw ();
+        int8_t frozen() const { return _frozen; }
 
 	AutomationEventList::size_type size() const { return events.size(); }
 	bool empty() const { return events.empty(); }
@@ -133,7 +134,7 @@ class AutomationList : public PBD::StatefulDestructible
 	}
 
 	void start_touch (double when);
-	void stop_touch (bool mark, double when);
+	void stop_touch (bool mark, double when, double value);
         bool touching() const { return g_atomic_int_get (&_touching); }
 
 	void set_yrange (double min, double max) {
