@@ -37,7 +37,7 @@ bool string_is_affirmative (const std::string& str);
 
 class XMLNode;
 
-Glib::ustring legalize_for_path (Glib::ustring);
+std::string legalize_for_path (std::string);
 
 void elapsed_time_to_str (char *buf, uint32_t seconds);
 std::ostream& operator<< (std::ostream& o, const ARDOUR::BBT_Time& bbt);
@@ -58,11 +58,11 @@ int cmp_nocase (const std::string& s, const std::string& s2);
 
 int tokenize_fullpath (std::string fullpath, std::string& path, std::string& name);
 
-int touch_file(Glib::ustring path);
+int touch_file(std::string path);
 
-Glib::ustring path_expand (Glib::ustring);
-Glib::ustring region_name_from_path (Glib::ustring path, bool strip_channels, bool add_channel_suffix = false, uint32_t total = 0, uint32_t this_one = 0);
-bool path_is_paired (Glib::ustring path, Glib::ustring& pair_base);
+std::string path_expand (std::string);
+std::string region_name_from_path (std::string path, bool strip_channels, bool add_channel_suffix = false, uint32_t total = 0, uint32_t this_one = 0);
+bool path_is_paired (std::string path, std::string& pair_base);
 
 void compute_equal_power_fades (nframes_t nframes, float* in, float* out);
 
