@@ -46,6 +46,7 @@
 #include <appleutility/CAAUParameter.h>
 
 #include <CoreFoundation/CoreFoundation.h>
+#include <CoreFoundation/CFRunLoop.h>
 #include <CoreServices/CoreServices.h>
 
 #include "i18n.h"
@@ -1494,7 +1495,11 @@ AUPlugin::automatable() const
 string
 AUPlugin::describe_parameter (uint32_t param)
 {
-	return descriptors[param].label;
+        if (param < descriptors.size()) {
+                return descriptors[param].label;
+        } else {
+                return "??";
+        }
 }
 
 void
@@ -2172,14 +2177,8 @@ AUPluginInfo::discover_by_description (PluginInfoList& plugs, CAComponentDescrip
 		
 		if (cached_io_configuration (info->unique_id, info->version, cacomp, info->cache, info->name)) {
 
-			/* here we have to map apple's wildcard system to a simple pair
-			   of values. in ::can_do() we use the whole system, but here
-			   we need a single pair of values. XXX probably means we should
-			   remove any use of these values.
-			*/
-
-			info->n_inputs = info->cache.io_configs.front().first;
-			info->n_outputs = info->cache.io_configs.front().second;
+			info->n_inputs = -1;
+			info->n_outputs = -1;
 
 			cerr << "detected AU: " << info->name.c_str() << "  (" << info->cache.io_configs.size() << " i/o configurations) - " << info->unique_id << endl;
 
@@ -2491,7 +2490,7 @@ AUPluginInfo::stringify_descriptor (const CAComponentDescription& desc)
 int
 AUPlugin::create_parameter_listener (AUEventListenerProc cb, void* arg, float interval_secs)
 {
-	CFRunLoopRef run_loop = (CFRunLoopRef) GetCFRunLoopFromEventLoop(GetCurrentEventLoop()); 
+        CFRunLoopRef run_loop =  CFRunLoopGetCurrent ();
 	CFStringRef  loop_mode = kCFRunLoopDefaultMode;
 
 	if (AUEventListenerCreate (cb, arg, run_loop, loop_mode, interval_secs, interval_secs, &_parameter_listener) != noErr) {
