@@ -232,7 +232,7 @@ setup_hardware_optimization (bool try_optimization)
                 }
 
 #elif defined (__APPLE__) && defined (BUILD_VECLIB_OPTIMIZATIONS)
-                long sysVersion = 0;
+                SInt32 sysVersion = 0;
 
                 if (noErr != Gestalt(gestaltSystemVersion, &sysVersion))
                         sysVersion = 0;
@@ -416,7 +416,7 @@ ARDOUR::new_change ()
 string
 ARDOUR::get_ardour_revision ()
 {
-	return "$Rev: 9622 $";
+	return "$Rev: 12031 $";
 }
 
 string
@@ -435,7 +435,7 @@ ARDOUR::get_user_ardour_path ()
 	/* create it if necessary */
 
 	if (g_mkdir_with_parents (path.c_str (), 0755)) {
-                cerr << "\n\n\nYour home folder is not writable (Ardour cannot create its settings folder there). Please fix this before running Ardour again."
+                cerr << "\n\n\nYour home folder is not writable (" << PROGRAM_NAME << " cannot create its settings folder there). Please fix this before running " << PROGRAM_NAME << " again."
                      << endl;
                 _exit (1);
 	}
