@@ -54,7 +54,7 @@ std::list<boost::weak_ptr<AudioSource> > SourceFactory::files_with_peaks;
 static void 
 peak_thread_work ()
 {
-	PBD::ThreadCreated (pthread_self(), string ("peakbuilder-") + to_string (pthread_self(), std::dec));
+	PBD::notify_gui_about_thread_creation (pthread_self(), string ("peakbuilder-") + to_string (pthread_self(), std::dec));
 
 	while (true) {
 
@@ -129,7 +129,6 @@ boost::shared_ptr<Source>
 SourceFactory::create (Session& s, const XMLNode& node, bool defer_peaks)
 {
 	try {
-
 		boost::shared_ptr<Source> ret (new SndFileSource (s, node));
 		if (setup_peakfile (ret, defer_peaks)) {
 			return boost::shared_ptr<Source>();
